@@ -21,19 +21,19 @@
 #ifndef SENDFILEITEMACTION_H
 #define SENDFILEITEMACTION_H
 
-#include <kfileitemactionplugin.h>
 #include <KFileItemListProperties>
+#include <KAbstractFileItemActionPlugin>
 
 class QAction;
 class KFileItemListProperties;
 class QWidget;
 
-class SendFileItemAction : public KFileItemActionPlugin
+class SendFileItemAction : public KAbstractFileItemActionPlugin
 {
 Q_OBJECT
 public:
-    SendFileItemAction(QObject* parent, const QVariantList &args);
-    virtual QList< QAction* > actions(const KFileItemListProperties& fileItemInfos, QWidget* parentWidget) const;
+    SendFileItemAction(QObject* parent, const QVariantList& args);
+    QList< QAction* > actions(const KFileItemListProperties& fileItemInfos, QWidget* parentWidget) override;
 
 private Q_SLOTS:
     void sendFile();
