@@ -15,18 +15,17 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef BATTERYPLUGIN_H
 #define BATTERYPLUGIN_H
 
-#include <QLoggingCategory>
 #include <core/kdeconnectplugin.h>
 
-#define PACKAGE_TYPE_BATTERY_REQUEST QStringLiteral("kdeconnect.battery.request")
+#define PACKET_TYPE_BATTERY QStringLiteral("kdeconnect.battery")
+#define PACKET_TYPE_BATTERY_REQUEST QStringLiteral("kdeconnect.battery.request")
 
-Q_DECLARE_LOGGING_CATEGORY(KDECONNECT_PLUGIN_BATTERY)
 class BatteryDbusInterface;
 
 class BatteryPlugin
@@ -38,9 +37,14 @@ public:
     explicit BatteryPlugin(QObject* parent, const QVariantList& args);
     ~BatteryPlugin() override;
 
-    bool receivePackage(const NetworkPackage& np) override;
+    bool receivePacket(const NetworkPacket& np) override;
     void connected() override;
 
+    // NB: This may be connected to zero or two signals in Solid::Battery -
+    // chargePercentageChanged and chargeStatusChanged.
+    // See inline comments for further details
+    void chargeChanged();
+
 private:
     // Keep these values in sync with THRESHOLD* constants in
     // kdeconnect-android:BatteryPlugin.java
