@@ -21,6 +21,7 @@
 
 #include "conversationmodel.h"
 #include "conversationlistmodel.h"
+#include "conversationssortfilterproxymodel.h"
 #include "kdeconnect-version.h"
 
 #include <QApplication>
@@ -32,13 +33,16 @@
 #include <KLocalizedContext>
 #include <KDBusService>
 
+#include "smshelper.h"
+
 int main(int argc, char *argv[])
 {
+    QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     QApplication app(argc, argv);
     KAboutData aboutData(QStringLiteral("kdeconnect.sms"),
-                         i18n("SMS Instant Messaging"),
-                         QStringLiteral(KDECONNECT_VERSION_STRING),
                          i18n("KDE Connect SMS"),
+                         QStringLiteral(KDECONNECT_VERSION_STRING),
+                         i18n("SMS Instant Messaging"),
                          KAboutLicense::GPL_V3,
                          i18n("(C) 2018-2019, KDE Connect Team"));
     aboutData.addAuthor(i18n("Simon Redman"), {}, QStringLiteral("simon@ergotech.com"));
@@ -62,10 +66,12 @@ int main(int argc, char *argv[])
 
     KDBusService service(KDBusService::Unique);
 
-    qmlRegisterType<OurSortFilterProxyModel>("org.kde.kdeconnect.sms", 1, 0, "QSortFilterProxyModel");
+    qmlRegisterType<ConversationsSortFilterProxyModel>("org.kde.kdeconnect.sms", 1, 0, "QSortFilterProxyModel");
     qmlRegisterType<ConversationModel>("org.kde.kdeconnect.sms", 1, 0, "ConversationModel");
     qmlRegisterType<ConversationListModel>("org.kde.kdeconnect.sms", 1, 0, "ConversationListModel");
 
+    qmlRegisterSingletonType<SmsHelper>("org.kde.kdeconnect.sms", 1, 0, "SmsHelper", SmsHelper::singletonProvider);
+
     QQmlApplicationEngine engine;
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
     engine.rootContext()->setContextProperties({
